/*

Copyright (C) NEC Corporation 2012. All Rights Reserved.
Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved.

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

*/

package com.necsoft.hinemos.webclient.monitor.form;

public class EventInfoPropertyForm {
    private String facilityId;

    private String pluginId;

    private String monitorId;

    private String monitorDetailId;

    private long receiveTime;

    /**
     * マネージャIPアドレス<br>
     * （左ペインのノードを選択する時検索用）
     */
    private String managerIpForSearch;

    /**
     * @return the facilityId
     */
    public String getFacilityId() {
        return facilityId;
    }

    /**
     * @param facilityId
     *            the facilityId to set
     */
    public void setFacilityId(String facilityId) {
        this.facilityId = facilityId;
    }

    /**
     * @return the pluginId
     */
    public String getPluginId() {
        return pluginId;
    }

    /**
     * @param pluginId
     *            the pluginId to set
     */
    public void setPluginId(String pluginId) {
        this.pluginId = pluginId;
    }

    /**
     * @return the monitorId
     */
    public String getMonitorId() {
        return monitorId;
    }

    /**
     * @param monitorId
     *            the monitorId to set
     */
    public void setMonitorId(String monitorId) {
        this.monitorId = monitorId;
    }

    public void setReceiveTime(long receiveTime) {
        this.receiveTime = receiveTime;
    }

    public long getReceiveTime() {
        return receiveTime;
    }

    public void setMonitorDetailId(String monitorDetailId) {
        this.monitorDetailId = monitorDetailId;
    }

    public String getMonitorDetailId() {
        return monitorDetailId;
    }

    public String getManagerIpForSearch() {
        return managerIpForSearch;
    }

    public void setManagerIpForSearch(String managerIpForSearch) {
        this.managerIpForSearch = managerIpForSearch;
    }

}
